@@ -145,7 +145,8 @@ as_Spatial = function(from) {
 	zm = class(from[[1]])[1]
 	if (zm %in% c("XYM", "XYZM"))
 		stop("geometries containing M not supported by sp")
-	StopZ = function(zm) { if (zm %in% c("XYZ", "XYZM")) stop("Z not supported") }
+	StopZ = function(zm) { if (zm %in% c("XYZ", "XYZM")) 
+		stop("Z not supported: try st_drop_zm first?") }
 	switch(class(from)[1],
 		"sfc_POINT" = sfc2SpatialPoints(from),
 		"sfc_MULTIPOINT" = sfc2SpatialMultiPoints(from),
