@@ -32,7 +32,7 @@ std::vector<OGRFieldType> SetupFields(OGRLayer *poLayer, Rcpp::List obj) {
 			throw std::invalid_argument("Layer creation failed.\n");
 		}
 	}
-	return(ret);
+	return ret;
 }
 
 // this is like an unlist -> dbl, but only does the first 6; if we'd do unlist on the POSIXlt
@@ -43,7 +43,7 @@ Rcpp::NumericVector get_dbl6(Rcpp::List in) {
 		Rcpp::NumericVector x = in(i);
 		ret(i) = x(0);
 	}
-	return(ret);
+	return ret;
 }
 
 void SetFields(OGRFeature *poFeature, std::vector<OGRFieldType> tp, Rcpp::List obj, size_t i = 0) {
@@ -97,20 +97,6 @@ void SetFields(OGRFeature *poFeature, std::vector<OGRFieldType> tp, Rcpp::List o
 	}
 }
 
-OGRSpatialReference *ref_from_sfc(Rcpp::List sfc) {
-	Rcpp::String p4s = sfc.attr("proj4string");
-	OGRSpatialReference *sref = new OGRSpatialReference;
-	if (p4s != NA_STRING) {
-		Rcpp::CharacterVector p4s_cv = sfc.attr("proj4string");
-		char *cp = p4s_cv[0];
-		if (sref->importFromProj4(cp) != OGRERR_NONE || *cp == '\0') {
-			sref->Release();
-			throw std::invalid_argument("Object with invalid proj4string.\n");
-		}
-	}
-	return(sref);
-}
-
 // [[Rcpp::export]]
 void CPL_write_ogr(Rcpp::List obj, Rcpp::CharacterVector dsn, Rcpp::CharacterVector layer,
 	Rcpp::CharacterVector driver, Rcpp::CharacterVector dco, Rcpp::CharacterVector lco,
@@ -129,8 +115,8 @@ void CPL_write_ogr(Rcpp::List obj, Rcpp::CharacterVector dsn, Rcpp::CharacterVec
 		Rcpp::Rcout << driver[0] << " driver not available." << std::endl;
 		throw std::invalid_argument("Driver not available.\n");
 	}  else if (! quiet)
-		Rcpp::Rcout << "Writing layer " << layer[0] << " to data source " << dsn[0] <<
-			" using driver " << driver << std::endl;
+		Rcpp::Rcout << "Writing layer `" << layer[0] << "' to data source `" << dsn[0] <<
+			"' using driver `" << driver[0] << "'" << std::endl;
 
 	// open data set:
 	std::vector <char *> options = create_options(dco, quiet);
@@ -141,13 +127,16 @@ void CPL_write_ogr(Rcpp::List obj, Rcpp::CharacterVector dsn, Rcpp::CharacterVec
 	}
 	Rcpp::CharacterVector clsv = geom.attr("class");
 	OGRwkbGeometryType wkbType = (OGRwkbGeometryType) make_type(clsv[0], dim[0], false, NULL, 0);
+	// read geometries:
+	OGRSpatialReference *sref;
+	std::vector<OGRGeometry *> geomv = ogr_from_sfc(geom, &sref);
 
 	// create layer:
 	options = create_options(lco, quiet);
-	OGRSpatialReference *sref = ref_from_sfc(geom); // breaks on errror
 	OGRLayer *poLayer = poDS->CreateLayer(layer[0], sref, wkbType, options.data());
-	if (poLayer == NULL)  {
+	if (sref != NULL)
 		sref->Release();
+	if (poLayer == NULL)  {
 		Rcpp::Rcout << "Creating layer " << layer[0]  <<  " failed." << std::endl;
 		GDALClose(poDS);
 		throw std::invalid_argument("Layer creation failed.\n");
@@ -155,8 +144,6 @@ void CPL_write_ogr(Rcpp::List obj, Rcpp::CharacterVector dsn, Rcpp::CharacterVec
 
 	// write feature attribute fields & geometries:
 	std::vector<OGRFieldType> fieldTypes = SetupFields(poLayer, obj);
-	std::vector<OGRGeometry *> geomv = ogr_from_sfc(geom, sref);
-	sref->Release();
 	if (! quiet) {
 		Rcpp::Rcout << "features:       " << geomv.size() << std::endl;
 		Rcpp::Rcout << "fields:         " << fieldTypes.size() << std::endl;
