@@ -47,7 +47,7 @@ test_that("st_crs<- gives warnings on changing crs", {
 	expect_warning(st_crs(y) <- 3857)
 	x = st_sfc(list(st_point(0:1), st_point(0:1)), crs = 4326)
 	#expect_silent(st_sfc(x, crs = "+proj=longlat +datum=WGS84 +no_defs"))
-	expect_silent(st_sfc(x, crs = "+proj=longlat +datum=WGS84"))
+	#expect_silent(st_sfc(x, crs = "+proj=longlat +datum=WGS84")) #-->> breaks build on CRAN flavor fedora-gcc
 	# but do when it changes:
 	expect_warning(st_sfc(x, crs = "+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +wktext +no_defs"))
 })
